@@ -6,7 +6,7 @@
 */
 /* libburn wrappers for libisoburn 
 
-   Copyright 2007 - 2011  Thomas Schmitt, <scdbackup@gmx.net> 
+   Copyright 2007 - 2014  Thomas Schmitt, <scdbackup@gmx.net> 
    Provided under GPL version 2 or later.
 */
 
@@ -375,7 +375,10 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
    readonly= 1;
  if(flag & 128)
    flag = (flag & ~ 16) | 8;
-   
+
+ ret= isoburn_find_emulator(o, d, 0);
+ if(ret >= 0 && *o != NULL)
+   isoburn_destroy(o, 0);
  ret= isoburn_new(o, 0);
  if(ret<=0)
    goto ex;
@@ -489,8 +492,9 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
          goto ex;
        if(ret>0) { /* point msc1 to last session */
          if((*o)->toc!=NULL) {
-           for(t= (*o)->toc; t->next!=NULL; t= t->next);
-            (*o)->fabricated_msc1= t->start_lba;
+           for(t= (*o)->toc; t->next!=NULL; t= t->next)
+             ; /* clang wants newline in empty loops */
+           (*o)->fabricated_msc1= t->start_lba;
          }
        }
      }
@@ -656,6 +660,19 @@ enum burn_disc_status isoburn_disc_get_status(struct burn_drive *drive)
 }
 
 
+int isoburn_disc_pretend_full_uncond(struct burn_drive *drive)
+{
+ int ret;
+ struct isoburn *o;
+
+ ret= isoburn_find_emulator(&o, drive, 0);
+ if(ret > 0 && o != NULL)
+   o->fabricated_disc_status= BURN_DISC_FULL;
+ ret= burn_disc_pretend_full_uncond(drive);
+ return(ret);
+}
+
+
 int isoburn_disc_erasable(struct burn_drive *d)
 {
  int ret;
@@ -669,6 +686,21 @@ int isoburn_disc_erasable(struct burn_drive *d)
 }
 
 
+static int isoburn_is_overwritable(struct burn_drive *drive, int flag)
+{
+ char name[80];
+ int profile, ret;
+ 
+ ret= burn_disc_get_profile(drive, &profile, name);
+ if(ret <= 0)
+   return(0);
+ if(profile == 0x12 || profile == 0x13 || profile == 0x1a || profile == 0x43)
+   return(1);
+ return(0);
+ 
+}
+
+
 void isoburn_disc_erase(struct burn_drive *drive, int fast)
 {
  int ret, do_pseudo_blank= 0, role;
@@ -702,7 +734,9 @@ void isoburn_disc_erase(struct burn_drive *drive, int fast)
    }
    if(o->emulation_mode > 0) { /* might be readonly with emulated sessions */
      ret= burn_disc_get_multi_caps(drive, BURN_WRITE_NONE, &caps, 0);
-     if(ret > 0 && caps->start_adr)
+     if(ret <= 0) /* Maybe because of burn_disc_pretend_full() */
+       do_pseudo_blank= isoburn_is_overwritable(drive, 0); /* known profiles */
+     else if(caps->start_adr)
        do_pseudo_blank= 1;
    }
    if(do_pseudo_blank) {
